@@ -186,44 +186,22 @@ class PluginClient:
             if not plugin_path.exists():
                 raise PluginValidationError(f"插件目录不存在: {plugin_dir}")
 
-            # 验证 plugin.json 或 plugin.yaml
-            plugin_json_path = plugin_path / "plugin.json"
+            # 验证 plugin.yaml
             plugin_yaml_path = plugin_path / "plugin.yaml"
             
-            if plugin_json_path.exists():
-                # 使用 plugin.json
-                with open(plugin_json_path, "r", encoding="utf-8") as f:
-                    plugin_config = json.load(f)
-            elif plugin_yaml_path.exists():
-                # 使用 plugin.yaml 并转换为 JSON 格式
+            if plugin_yaml_path.exists():
+                # 使用 plugin.yaml
                 import yaml
                 with open(plugin_yaml_path, "r", encoding="utf-8") as f:
-                    yaml_config = yaml.safe_load(f)
-                
-                # 转换为 PluginManifest 格式
-                plugin_config = {
-                    "name": yaml_config.get("name", ""),
-                    "display_name": yaml_config.get("display_name", yaml_config.get("name", "")),
-                    "description": yaml_config.get("description", ""),
-                    "category": yaml_config.get("category", "utility"),
-                    "version": yaml_config.get("version", "1.0.0"),
-                    "author": yaml_config.get("author", ""),
-                    "icon": yaml_config.get("icon", ""),
-                    "config": yaml_config.get("ui", {}),
-                    "script": yaml_config.get("execution", {}).get("main_script", "main.py")
-                }
-                
-                # 创建 plugin.json 文件
-                with open(plugin_json_path, "w", encoding="utf-8") as f:
-                    json.dump(plugin_config, f, indent=2, ensure_ascii=False)
+                    plugin_config = yaml.safe_load(f)
             else:
-                raise PluginValidationError(f"plugin.json 或 plugin.yaml 不存在: {plugin_path}")
+                raise PluginValidationError(f"plugin.yaml 不存在: {plugin_path}")
 
             # 验证必需字段
-            required_fields = ["name", "version", "script"]
+            required_fields = ["name", "version"]
             for field in required_fields:
                 if field not in plugin_config:
-                    raise PluginValidationError(f"plugin.json 缺少必需字段: {field}")
+                    raise PluginValidationError(f"plugin.yaml 缺少必需字段: {field}")
 
             # 确定输出路径
             if not output_path:
